MessageRenderContext class

Context injected into MessageTypePlugin.bubbleBuilder. Provides position metadata and action callbacks — keeps plugins UI-agnostic.

Constructors

MessageRenderContext({required bool isOwnMessage, required bool isFirstInGroup, required bool isLastInGroup, required void onReact(String emoji), required void onReply(), required void onEdit(), required void onDelete(), required void onPin(), required void onStar(), required void onTap(), required void onLongPress(), required void onRetry(), bool isHighlighted = false, bool isSelected = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isFirstInGroup bool
final
isHighlighted bool
final
isLastInGroup bool
final
isOwnMessage bool
final
isSelected bool
final
onDelete → void Function()
final
onEdit → void Function()
final
onLongPress → void Function()
final
onPin → void Function()
final
onReact → void Function(String emoji)
final
onReply → void Function()
final
onRetry → void Function()
final
onStar → void Function()
final
onTap → void Function()
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited