RestConfig class

REST polling configuration.

Constructors

RestConfig({required String baseUrl, Map<String, String> defaultHeaders = const {'Content-Type' : 'application/json'}, Duration pollInterval = const Duration(seconds: 3)})
const

Properties

baseUrl String
final
defaultHeaders Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
pollInterval Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited