CodePayload class
- Inheritance
-
- Object
- MessagePayload
- CodePayload
Constructors
- CodePayload({required String code, String language = 'plaintext', String? filename})
-
const
-
CodePayload.fromJson(Map<
String, Object?> j) -
factory
Properties
- code → String
-
final
- filename → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- language → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeId → String
-
Must match the corresponding MessageTypePlugin.id.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited