FileMessagePlugin class
- Inheritance
-
- Object
- MessageTypePlugin
- FileMessagePlugin
Constructors
- FileMessagePlugin()
-
const
Properties
- displayName → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
no setteroverride
- id → String
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsEditing → bool
-
no setterinherited
- supportsForwarding → bool
-
no setterinherited
Methods
-
bubbleBuilder(
BuildContext context, Message message, MessageRenderContext ctx) → Widget -
override
-
deserialize(
Map< String, Object?> json) → MessagePayload -
override
-
fallbackText(
Message message) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
previewBuilder(
BuildContext context, Message message) → Widget -
override
-
serialize(
MessagePayload payload) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited