FilePayload class

Inheritance

Constructors

FilePayload({required String url, required String filename, required String mimeType, int? fileSizeBytes})
const
FilePayload.fromJson(Map<String, Object?> j)
factory

Properties

filename String
final
fileSizeBytes int?
final
hashCode int
The hash code for this object.
no setterinherited
mimeType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeId String
Must match the corresponding MessageTypePlugin.id.
no setteroverride
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited