ImagePayload class

Inheritance

Constructors

ImagePayload({required String url, String? thumbnailUrl, int? width, int? height, String? caption, int? fileSizeBytes})
const
ImagePayload.fromJson(Map<String, Object?> j)
factory

Properties

caption String?
final
fileSizeBytes int?
final
hashCode int
The hash code for this object.
no setterinherited
height int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnailUrl String?
final
typeId String
Must match the corresponding MessageTypePlugin.id.
no setteroverride
url String
final
width int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited