PollOption class

Constructors

PollOption({required String id, required String text, List<String> voterIds = const []})
const
PollOption.fromJson(Map<String, Object?> j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
voteCount int
no setter
voterIds List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited