PollPayload class

Inheritance

Constructors

PollPayload({required String question, required List<PollOption> options, bool multipleChoice = false, bool isEnded = false, DateTime? endsAt})
const
PollPayload.fromJson(Map<String, Object?> j)
factory

Properties

endsAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
isEnded bool
final
multipleChoice bool
final
options List<PollOption>
final
question String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalVotes int
no setter
typeId String
Must match the corresponding MessageTypePlugin.id.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited