StickerPayload class

Inheritance

Constructors

StickerPayload({required String packId, required String stickerId, String? url, String? emoji})
const
StickerPayload.fromJson(Map<String, Object?> j)
factory

Properties

emoji String?
final
hashCode int
The hash code for this object.
no setterinherited
packId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stickerId String
final
typeId String
Must match the corresponding MessageTypePlugin.id.
no setteroverride
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited