StickerPlugin class

Implemented types

Constructors

StickerPlugin()

Properties

displayName String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
icon IconData
no setteroverride
id String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsEditing bool
no setteroverride
supportsForwarding bool
no setteroverride

Methods

bubbleBuilder(BuildContext context, Message m, MessageRenderContext ctx) Widget
override
deserialize(Map<String, Object?> json) MessagePayload
override
fallbackText(Message m) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
previewBuilder(BuildContext context, Message m) Widget
override
serialize(MessagePayload p) Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited