SystemEventPayload class

Inheritance

Constructors

SystemEventPayload({required String event, Map<String, String> params = const {}})
const
SystemEventPayload.fromJson(Map<String, Object?> j)
factory

Properties

event String
Event type: 'joined' | 'left' | 'added' | 'removed' | 'renamed' | 'avatar_changed' | 'call_started' | 'call_ended' | 'custom'
final
eventIcon IconData
no setter
hashCode int
The hash code for this object.
no setterinherited
localizedText String
no setter
params Map<String, String>
Template params for localisation (e.g. {'user': 'Ali', 'name': 'Team Chat'}).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeId String
Must match the corresponding MessageTypePlugin.id.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited