VideoPayload class

Inheritance

Constructors

VideoPayload({required String url, String? thumbnailUrl, Duration? duration, String? caption, int? fileSizeBytes})
const
VideoPayload.fromJson(Map<String, Object?> j)
factory

Properties

caption String?
final
duration Duration?
final
fileSizeBytes int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnailUrl String?
final
typeId String
Must match the corresponding MessageTypePlugin.id.
no setteroverride
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited