WebSocketConfig class
Configuration for the WebSocket transport.
Constructors
-
WebSocketConfig({required Uri uri, Map<
String, String> headers = const {}, Duration pingInterval = const Duration(seconds: 30), Duration connectTimeout = const Duration(seconds: 10), int maxReconnectAttempts = 10, Duration initialReconnectDelay = const Duration(seconds: 1), Duration maxReconnectDelay = const Duration(seconds: 30)}) -
const
Properties
- connectTimeout → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
final
- initialReconnectDelay → Duration
-
final
- maxReconnectAttempts → int
-
final
- maxReconnectDelay → Duration
-
final
- pingInterval → Duration
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → Uri
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited