ContactPayload class
- Inheritance
-
- Object
- MessagePayload
- ContactPayload
Constructors
- ContactPayload({required String name, String? phone, String? email, String? avatarUrl})
-
const
-
ContactPayload.fromJson(Map<
String, Object?> j) -
factory
Properties
- avatarUrl → String?
-
final
- email → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- phone → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeId → String
-
Must match the corresponding MessageTypePlugin.id.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited