LocationPayload class
- Inheritance
-
- Object
- MessagePayload
- LocationPayload
Constructors
- LocationPayload({required double latitude, required double longitude, String? address, String? label})
-
const
-
LocationPayload.fromJson(Map<
String, Object?> j) -
factory
Properties
- address → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
final
- latitude → double
-
final
- longitude → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeId → String
-
Must match the corresponding MessageTypePlugin.id.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited