TextPayload class
- Inheritance
-
- Object
- MessagePayload
- TextPayload
Constructors
- TextPayload({required String text})
-
const
-
TextPayload.fromJson(Map<
String, Object?> j) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
final
- typeId → String
-
Must match the corresponding MessageTypePlugin.id.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited